@@ -47,10 +47,16 @@ ColorMapEditor::ColorMapEditor(QWidget* parent)
 table = new QTableWidget();
 table->setColumnCount(2);
 table->setSelectionMode(QAbstractItemView::SingleSelection);
-table->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
 table->verticalHeader()->hide();		
+#if QT_VERSION >= 0x050000
+table->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+table->horizontalHeader()->setSectionsClickable( false );
+table->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
+#else
+table->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
 table->horizontalHeader()->setClickable( false );
 table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+#endif
 table->viewport()->setMouseTracking(true);
 table->viewport()->installEventFilter(this);
 table->setHorizontalHeaderLabels(QStringList() << tr("Level") << tr("Color"));
@@ -124,7 +130,7 @@ for (int i = 0; i < rows; i++)
 		
 	QColor c = QColor(map.rgb(QwtDoubleInterval(0, 1), colors[i]));
 	it = new QTableWidgetItem(c.name());
-	it->setFlags(Qt::ItemFlags(!Qt::ItemIsEditable));
+	it->setFlags(it->flags() & (~Qt::ItemIsEditable));
 	it->setBackground(QBrush(c));
 	it->setForeground(QBrush(c));
     table->setItem(i, 1, it);
@@ -156,7 +162,7 @@ QTableWidgetItem *it = new QTableWidgetItem(QString::number(val));
 table->setItem(row, 0, it);
 		
 it = new QTableWidgetItem(c.name());
-it->setFlags(Qt::ItemFlags(!Qt::ItemIsEditable));
+it->setFlags(it->flags() & (~Qt::ItemIsEditable));
 it->setBackground(QBrush(c));
 it->setForeground(QBrush(c));
 table->setItem(row, 1, it);
