@@ -32,7 +32,6 @@
 #include "Graph.h"
 #include "Matrix.h"
 #include "ColorButton.h"
-#include "ColorBox.h"
 
 #include <QLocale>
 #include <QPushButton>
@@ -61,7 +60,7 @@
 #include <QFontMetrics>
 #include <QSettings>
 
-ConfigDialog::ConfigDialog( QWidget* parent, Qt::WFlags fl )
+ConfigDialog::ConfigDialog( QWidget* parent, Qt::WindowFlags fl )
     : QDialog( parent, fl )
 {
 	// get current values from app window
@@ -697,8 +696,8 @@ void ConfigDialog::initFittingPage()
 
 	lblPeaksColor = new QLabel();
 	multiPeakLayout->addWidget(lblPeaksColor);
-	boxPeaksColor = new ColorBox(0);
-	boxPeaksColor->setCurrentIndex(app->peakCurvesColor);
+	boxPeaksColor = new ColorButton();
+	boxPeaksColor->setColor(app->peakCurvesColor);
 	multiPeakLayout->addWidget(boxPeaksColor);
 
 	groupBoxFitParameters = new QGroupBox();
@@ -1102,8 +1101,8 @@ void ConfigDialog::apply()
 	// 2D plots page: print tab
 	app->d_print_cropmarks = boxPrintCropmarks->isChecked();
 	app->d_scale_plots_on_print = boxScaleLayersOnPrint->isChecked();
-	QWidgetList *windows = app->windowsList();
-	foreach(QWidget *w, *windows)
+	QList<MyWidget*> windows = app->windowsList();
+	foreach(MyWidget *w, windows)
 	{
 		if (w->inherits("MultiLayer"))
 		{
@@ -1111,7 +1110,6 @@ void ConfigDialog::apply()
 			((MultiLayer*)w)->printCropmarks(boxPrintCropmarks->isChecked());
 		}
 	}
-	delete windows;
 	// general page: application tab
 	app->changeAppFont(appFont);
 	setFont(appFont);
@@ -1146,7 +1144,7 @@ void ConfigDialog::apply()
 	int currentBoxIndex = boxDefaultNumericFormat->currentIndex();
 	if (currentBoxIndex > -1)
 	{
-		app->d_default_numeric_format = boxDefaultNumericFormat->itemData(currentBoxIndex).toChar().toAscii();
+		app->d_default_numeric_format = boxDefaultNumericFormat->itemData(currentBoxIndex).toChar().toLatin1();
 	}
 
     if(boxUseGroupSeparator->isChecked())
@@ -1185,7 +1183,7 @@ void ConfigDialog::apply()
 	app->fitPoints = generatePointsBox->value();
 	app->generateUniformFitPoints = generatePointsBtn->isChecked();
 	app->generatePeakCurves = groupBoxMultiPeak->isChecked();
-	app->peakCurvesColor = boxPeaksColor->currentIndex();
+	app->peakCurvesColor = boxPeaksColor->color();
 	app->fit_scale_errors = scaleErrorsBox->isChecked();
 	app->d_2_linear_fit_points = linearFit2PointsBox->isChecked();
 	app->saveSettings();
