@@ -30,6 +30,7 @@
 #include "Bar.h"
 #include "Cone3D.h"
 #include "MyParser.h"
+#include "ColorButton.h"
 #include "core/column/Column.h"
 
 #include <QApplication>
@@ -44,8 +45,8 @@
 #include <QCursor>
 #include <QImageWriter>
 
-#include <qwtplot3d/qwt3d_io_gl2ps.h>
-#include <qwtplot3d/qwt3d_coordsys.h>
+#include <qwt3d_io_gl2ps.h>
+#include <qwt3d_coordsys.h>
 
 #include <gsl/gsl_vector.h>
 #include <fstream>
@@ -70,7 +71,7 @@ double UserFunction::operator()(double x, double y)
 		parser.DefineVar("x", &x);
 		parser.DefineVar("y", &y);
 
-		parser.SetExpr((const std::string)formula.toAscii().constData());
+		parser.SetExpr((const std::string)formula.toUtf8().constData());
 		result=parser.Eval();
 	}
 	catch(mu::ParserError &e)
@@ -84,7 +85,7 @@ UserFunction::~UserFunction()
 {
 }
 
-	Graph3D::Graph3D(const QString& label, QWidget* parent, const char* name, Qt::WFlags f)
+	Graph3D::Graph3D(const QString& label, QWidget* parent, const char* name, Qt::WindowFlags f)
 : MyWidget(label,parent,name,f)
 {
 	initPlot();
@@ -105,7 +106,8 @@ void Graph3D::initPlot()
     connect(d_timer, SIGNAL(timeout()), this, SLOT(rotate()) );
 	ignoreFonts = false;
 
-	sp = new SurfacePlot(this);
+	QWidget* d_main_widget = new QWidget();
+	sp = new SurfacePlot(d_main_widget);
 	sp->resize(500,400);
 	sp->installEventFilter(this);
 	sp->setRotation(30,0,15);
@@ -164,6 +166,7 @@ void Graph3D::initPlot()
 	conesQuality = 32; conesRad = 0.5;
 
 	style_ = NOPLOT;
+	this->setWidget(d_main_widget);
 	initCoord();
 
 	connect(sp,SIGNAL(rotationChanged(double, double, double)),this,SLOT(rotationChanged(double, double, double)));
@@ -1695,26 +1698,28 @@ void Graph3D::scaleFonts(double factor)
 
 void Graph3D::resizeEvent ( QResizeEvent *e)
 {
-	QSize size=e->size();
-
 	sp->makeCurrent();
-	sp->resize(size);
+	sp->resize(e->size());
 
 	if (!ignoreFonts && this->isVisible())
 	{
-		QSize oldSize=e->oldSize();
-		double ratio=(double)size.height()/(double)oldSize.height();
+		double ratio=(double)e->size().height()/(double)e->oldSize().height();
 		scaleFonts(ratio);
 	}
 
 	sp->updateGL();
 	emit resizedWindow(this);
 	emit modified();
+	QMdiSubWindow::resizeEvent(e);
 }
 
 void Graph3D::contextMenuEvent(QContextMenuEvent *e)
 {
-	emit showContextMenu();
+	if (widget()->geometry().contains(e->pos())) {
+		emit showContextMenu();
+	} else {
+		emit showTitleBarMenu();
+	}
 	e->accept();
 }
 
@@ -2088,7 +2093,7 @@ bool Graph3D::eventFilter(QObject *object, QEvent *e)
 	if (e->type() == QEvent::MouseButtonDblClick && object == (QObject *)this->sp)
 	{
 		emit showOptionsDialog();
-		return TRUE;
+		return true;
 	}
 	return MyWidget::eventFilter(object, e);
 }
@@ -2527,21 +2532,21 @@ QString Graph3D::saveToString(const QString& geometry)
 
 	s+="title\t";
 	s+=title+"\t";
-	s+=titleCol.name()+"\t";
+	s+=COLORNAME(titleCol)+"\t";
 	s+=titleFnt.family()+"\t";
 	s+=QString::number(titleFnt.pointSize())+"\t";
 	s+=QString::number(titleFnt.weight())+"\t";
 	s+=QString::number(titleFnt.italic())+"\n";
 
 	s+="colors\t";
-	s+=meshCol.name()+"\t";
-	s+=axesCol.name()+"\t";
-	s+=numCol.name()+"\t";
-	s+=labelsCol.name()+"\t";
-	s+=bgCol.name()+"\t";
-	s+=gridCol.name()+"\t";
-	s+=fromColor.name()+"\t";
-	s+=toColor.name()+"\t";
+	s+=COLORNAME(meshCol)+"\t";
+	s+=COLORNAME(axesCol)+"\t";
+	s+=COLORNAME(numCol)+"\t";
+	s+=COLORNAME(labelsCol)+"\t";
+	s+=COLORNAME(bgCol)+"\t";
+	s+=COLORNAME(gridCol)+"\t";
+	s+=COLORNAME(fromColor)+"\t";
+	s+=COLORNAME(toColor)+"\t";
 	s+=QString::number(alpha) + "\t" + color_map + "\n";
 
 	s+="axesLabels\t";
