@@ -28,8 +28,8 @@
  ***************************************************************************/
 #include "ApplicationWindow.h"
 #include "PlotDialog.h"
-#include "ColorBox.h"
 #include "ColorButton.h"
+#include "PenWidget.h"
 #include "PatternBox.h"
 #include "SymbolBox.h"
 #include "Table.h"
@@ -59,14 +59,13 @@
 #include <QFileDialog>
 #include <QGroupBox>
 #include <QFontDialog>
-#include <QColorDialog>
 #include <QShortcut>
 #include <QKeySequence>
 #include <QDoubleSpinBox>
 #include <QMenu>
 #include <QDateTime>
 
-PlotDialog::PlotDialog(bool showExtended, QWidget* parent, Qt::WFlags fl )
+PlotDialog::PlotDialog(bool showExtended, QWidget* parent, Qt::WindowFlags fl )
 : QDialog(parent, fl),
   d_ml(0)
 {
@@ -201,8 +200,13 @@ void PlotDialog::showPlotAssociations(QTreeWidgetItem *item, int)
 	}
 	else
 	{
+#if QT_VERSION >= 0x050000
 	    close();
+#endif
         app->showPlotAssociations(((CurveTreeItem *)item)->plotItemIndex());
+#if QT_VERSION < 0x050000
+	    close();
+#endif
 	}
 }
 
@@ -219,7 +223,9 @@ void PlotDialog::editCurve()
   int index = item->plotItemIndex();
   int curveType = ((PlotCurve *)item->plotItem())->type();
 
+#if QT_VERSION >= 0x050000
   close();
+#endif
 
   if (app)
     {
@@ -228,6 +234,10 @@ void PlotDialog::editCurve()
       else
         app->showPlotAssociations(index);
     }
+
+#if QT_VERSION < 0x050000
+  close();
+#endif
 }
 
 void PlotDialog::changePlotType(int new_curve_type)
@@ -364,9 +374,9 @@ void PlotDialog::initLayerPage()
 	connect(boxCanvasTransparency, SIGNAL(valueChanged(int)), this, SLOT(updateCanvasTransparency(int)));
 	connect(boxAntialiasing, SIGNAL(toggled(bool)), this, SLOT(updateAntialiasing(bool)));
 	connect(boxMargin, SIGNAL(valueChanged (int)), this, SLOT(changeMargin(int)));
-	connect(boxBorderColor, SIGNAL(clicked()), this, SLOT(pickBorderColor()));
-	connect(boxBackgroundColor, SIGNAL(clicked()), this, SLOT(pickBackgroundColor()));
-	connect(boxCanvasColor, SIGNAL(clicked()), this, SLOT(pickCanvasColor()));
+	connect(boxBorderColor, SIGNAL(changed(QColor)), this, SLOT(pickBorderColor(QColor)));
+	connect(boxBackgroundColor, SIGNAL(changed(QColor)), this, SLOT(pickBackgroundColor(QColor)));
+	connect(boxCanvasColor, SIGNAL(changed(QColor)), this, SLOT(pickCanvasColor(QColor)));
 	connect(boxBorderWidth,SIGNAL(valueChanged (int)), this, SLOT(updateBorder(int)));
 }
 
@@ -377,7 +387,7 @@ void PlotDialog::initPiePage()
 	QGridLayout *gl1 = new QGridLayout();
 	gl1->addWidget(new QLabel( tr( "Color" )), 0, 0);
 
-	boxPieLineColor = new ColorBox();
+	boxPieLineColor = new ColorButton();
 	gl1->addWidget(boxPieLineColor, 0, 1);
 
 	gl1->addWidget(new QLabel(tr( "Style" )), 1, 0);
@@ -400,7 +410,7 @@ void PlotDialog::initPiePage()
 	QGridLayout *gl2 = new QGridLayout();
 	gl2->addWidget(new QLabel( tr( "First color" )), 0, 0);
 
-	boxFirstColor = new ColorBox();
+	boxFirstColor = new ColorButton();
 	gl2->addWidget(boxFirstColor, 0, 1);
 
 	gl2->addWidget(new QLabel( tr( "Pattern" )), 1, 0);
@@ -459,6 +469,7 @@ void PlotDialog::initAxesPage()
 	boxYAxis->addItem(tr("Right"));
 	gl->addWidget(boxYAxis, 1, 1);
     gl->setRowStretch (2, 1);
+    gl->setColumnStretch(2,1);
 
 	axesPage = new QWidget();
 	QHBoxLayout* hlayout = new QHBoxLayout(axesPage);
@@ -483,33 +494,15 @@ void PlotDialog::initLinePage()
 	boxConnect->addItem(tr("Vertical Steps"));
 	gl1->addWidget(boxConnect, 0, 1);
 
-	gl1->addWidget(new QLabel(tr( "Style" )), 1, 0);
-	boxLineStyle = new QComboBox();
-	boxLineStyle->setEditable(false);
-	boxLineStyle->addItem("_____");
-	boxLineStyle->addItem("_ _ _");
-	boxLineStyle->addItem(".....");
-	boxLineStyle->addItem("_._._");
-	boxLineStyle->addItem("_.._..");
-	gl1->addWidget(boxLineStyle, 1, 1);
-
-	gl1->addWidget(new QLabel(tr( "Width" )), 2, 0);
-	boxLineWidth = new QSpinBox();
-	boxLineWidth->setMinimum( 1 );
-	boxLineWidth->setValue( 1 );
-	gl1->addWidget(boxLineWidth, 2, 1);
-
-	gl1->addWidget(new QLabel(tr( "Color" )), 3, 0);
-    boxLineColor = new ColorButton();
-    gl1->addWidget(boxLineColor, 3, 1);
-    gl1->setRowStretch (4, 1);
+	penWidget = new PenWidget(this,QPen());
+	gl1->addWidget(penWidget, 1, 0, 1, 2);
 
 	fillGroupBox = new QGroupBox(tr( "Fill area under curve" ));
 	fillGroupBox->setCheckable(true);
 	QGridLayout *gl2 = new QGridLayout(fillGroupBox);
-    gl2->addWidget(new QLabel(tr( "Fill color" )), 0, 0);
-    boxAreaColor = new ColorButton();
-    gl2->addWidget(boxAreaColor, 0, 1);
+	gl2->addWidget(new QLabel(tr( "Fill color" )), 0, 0);
+	boxAreaColor = new ColorButton();
+	gl2->addWidget(boxAreaColor, 0, 1);
 	gl2->addWidget(new QLabel(tr( "Pattern" )), 1, 0);
 	boxPattern = new PatternBox();
 	gl2->addWidget(boxPattern, 1, 1);
@@ -521,10 +514,8 @@ void PlotDialog::initLinePage()
 	hlayout->addWidget(fillGroupBox);
 	privateTabWidget->addTab( linePage, tr( "Line" ) );
 
-    connect(boxLineColor, SIGNAL(clicked()), this, SLOT(pickBoxLineColor()));
 	connect(boxConnect, SIGNAL(activated(int)), this, SLOT(acceptParams()));
-	connect(boxLineStyle, SIGNAL(activated(int)), this, SLOT(acceptParams()));
-    connect(boxAreaColor, SIGNAL(clicked()), this, SLOT(pickBoxAreaColor()));
+	connect(penWidget, SIGNAL(penChanged(QPen)), this, SLOT(acceptParams()));
 	connect(boxPattern, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(fillGroupBox, SIGNAL(toggled(bool)), this, SLOT(showAreaColor(bool)));
 	connect(fillGroupBox, SIGNAL(clicked()), this, SLOT(acceptParams()));
@@ -544,16 +535,17 @@ void PlotDialog::initSymbolsPage()
     gl->addWidget(boxSymbolSize, 1, 1);
 	boxFillSymbol = new QCheckBox( tr( "Fill Color" ));
     gl->addWidget(boxFillSymbol, 2, 0);
-	boxFillColor = new ColorBox();
-    gl->addWidget(boxFillColor, 2, 1);
-    gl->addWidget(new QLabel(tr( "Edge Color" )), 3, 0);
-	boxSymbolColor = new ColorBox();
-    gl->addWidget(boxSymbolColor, 3, 1);
+	boxFillColor = new ColorButton();
+	gl->addWidget(boxFillColor, 2, 1);
+	gl->addWidget(new QLabel(tr( "Edge Color" )), 3, 0);
+	boxSymbolColor = new ColorButton();
+	gl->addWidget(boxSymbolColor, 3, 1);
     gl->addWidget(new QLabel(tr( "Edge Width" )), 4, 0);
 	boxPenWidth = new QSpinBox();
     boxPenWidth->setRange(1, 100);
     gl->addWidget(boxPenWidth, 4, 1);
     gl->setRowStretch (5, 1);
+    gl->setColumnStretch(2,1);
 
     symbolPage = new QWidget();
 	QHBoxLayout* hl = new QHBoxLayout(symbolPage);
@@ -561,9 +553,7 @@ void PlotDialog::initSymbolsPage()
 
 	privateTabWidget->addTab(symbolPage, tr( "Symbol" ));
 
-	connect(boxSymbolColor, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(boxSymbolStyle, SIGNAL(activated(int)), this, SLOT(acceptParams()));
-	connect(boxFillColor, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(boxFillSymbol, SIGNAL(clicked()), this, SLOT(fillSymbols()));
 }
 
@@ -705,11 +695,11 @@ void PlotDialog::initPercentilePage()
 
     boxFillSymbols = new QCheckBox(tr( "Fill Color" ));
     gl2->addWidget(boxFillSymbols, 1, 0);
-	boxPercFillColor = new ColorBox();
+	boxPercFillColor = new ColorButton();
     gl2->addWidget(boxPercFillColor, 1, 1);
 
     gl2->addWidget(new QLabel(tr( "Edge Color" )), 2, 0);
-	boxEdgeColor = new ColorBox();
+	boxEdgeColor = new ColorButton();
     gl2->addWidget(boxEdgeColor, 2, 1);
 
     gl2->addWidget(new QLabel(tr( "Edge Width" )), 3, 0);
@@ -730,8 +720,6 @@ void PlotDialog::initPercentilePage()
 	connect(box99Style, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(box1Style, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(box1Style, SIGNAL(activated(int)), this, SLOT(acceptParams()));
-	connect(boxEdgeColor, SIGNAL(activated(int)), this, SLOT(acceptParams()));
-	connect(boxPercFillColor, SIGNAL(activated(int)), this, SLOT(acceptParams()));
 	connect(boxFillSymbols, SIGNAL(clicked()), this, SLOT(fillBoxSymbols()));
 }
 
@@ -805,8 +793,6 @@ void PlotDialog::initSpectrogramPage()
     gl1->addWidget(boxContourStyle, 2, 1);
     hl2->addWidget(defaultPenBox);
 
-  	connect(levelsColorBox, SIGNAL(clicked()), this, SLOT(pickContourLinesColor()));
-
   	axisScaleBox = new QGroupBox(tr( "Color Bar Scale" ));
   	axisScaleBox->setCheckable (true);
 
@@ -897,11 +883,11 @@ void PlotDialog::initErrorsPage()
 	hl->addWidget(gb2);
     privateTabWidget->addTab( errorsPage, tr( "Error Bars" ) );
 
-	connect(colorBox, SIGNAL(clicked()), this, SLOT(pickErrorBarsColor()));
 	connect(xBox, SIGNAL(clicked()), this, SLOT(changeErrorBarsType()));
 	connect(plusBox, SIGNAL(clicked()), this, SLOT(changeErrorBarsPlus()));
 	connect(minusBox, SIGNAL(clicked()), this, SLOT(changeErrorBarsMinus()));
 	connect(throughBox, SIGNAL(clicked()), this, SLOT(changeErrorBarsThrough()));
+	connect(colorBox, SIGNAL(changed(QColor)), this, SLOT(pickErrorBarsColor(QColor)));
 }
 
 void PlotDialog::initHistogramPage()
@@ -962,7 +948,7 @@ void PlotDialog::initVectPage()
     QGroupBox *gb1 = new QGroupBox();
     QGridLayout *gl1 = new QGridLayout(gb1);
     gl1->addWidget(new QLabel(tr( "Color" )), 0, 0);
-	vectColorBox = new ColorBox();
+	vectColorBox = new ColorButton();
     gl1->addWidget(vectColorBox, 0, 1);
     gl1->addWidget(new QLabel(tr( "Line Width" )), 1, 0);
 	vectWidthBox = new QSpinBox();
@@ -1243,32 +1229,8 @@ void PlotDialog::changeErrorBarsType()
                          throughBox->isChecked());
 }
 
-void PlotDialog::pickBoxLineColor()
+void PlotDialog::pickErrorBarsColor(QColor color)
 {
-    QColor color = QColorDialog::getColor(boxLineColor->color(), this);
-    if ( !color.isValid() || color == boxLineColor->color() )
-        return;
-
-    boxLineColor->setColor(color);
-}
-
-void PlotDialog::pickBoxAreaColor()
-{
-    QColor color = QColorDialog::getColor(boxAreaColor->color(), this);
-    if ( !color.isValid() || color == boxAreaColor->color() )
-        return;
-
-    boxAreaColor->setColor(color);
-}
-
-void PlotDialog::pickErrorBarsColor()
-{
-  QColor color = QColorDialog::getColor(colorBox->color(), this);
-  if ( !color.isValid() || color == colorBox->color() )
-    return;
-
-  colorBox->setColor (color);
-
   CurveTreeItem *item = (CurveTreeItem *)listBox->currentItem();
   if (!item)
     return;
@@ -1541,13 +1503,11 @@ void PlotDialog::setActiveLayer(LayerItem *item)
   QColor c = p->paletteBackgroundColor();
   boxBackgroundTransparency->setValue(c.alpha());
   boxBackgroundColor->setEnabled(c.alpha());
-  c.setAlpha(255);
   boxBackgroundColor->setColor(c);
 
   c = p->canvasBackground();
   boxCanvasTransparency->setValue(c.alpha());
   boxCanvasColor->setEnabled(c.alpha());
-  c.setAlpha(255);
   boxCanvasColor->setColor(c);
 
   boxAntialiasing->setChecked(g->antialiasing());
@@ -1579,7 +1539,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
       boxPieLineWidth->setValue(pie->pen().width());
       boxPieLineColor->setColor(pie->pen().color());
       setPiePenStyle(pie->pen().style());
-      boxFirstColor->setCurrentIndex(pie->firstColor());
+      boxFirstColor->setColor(pie->firstColor());
       return;
     }
 
@@ -1633,9 +1593,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
     style = 6;
   boxConnect->setCurrentIndex(style);
 
-  setPenStyle(c->pen().style());
-  boxLineColor->setColor(c->pen().color());
-  boxLineWidth->setValue(c->pen().width());
+  penWidget->setPen(c->pen());
   fillGroupBox->blockSignals(true);
   fillGroupBox->setChecked(c->brush().style() != Qt::NoBrush );
   fillGroupBox->blockSignals(false);
@@ -1699,10 +1657,10 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
           xBox->setChecked(err->xErrors());
           widthBox->setEditText(QString::number(err->width()));
           capBox->setEditText(QString::number(err->capLength()));
-          colorBox->setColor(err->color());
           throughBox->setChecked(err->throughSymbol());
           plusBox->setChecked(err->plusSide());
           minusBox->setChecked(err->minusSide());
+          colorBox->setColor(err->color());
         }
     }
 
@@ -1873,9 +1831,8 @@ bool PlotDialog::acceptParams()
         if (!fillGroupBox->isChecked())
           br = QBrush();
         graph->setCurveBrush(index, br);
-        QPen pen = QPen(boxLineColor->color(),boxLineWidth->value(),Graph::getPenStyle(boxLineStyle->currentIndex()));
         QwtPlotCurve *curve = (QwtPlotCurve *)plotItem;
-        curve->setPen(pen);
+        curve->setPen(penWidget->pen());
       }
     }
   else if (privateTabWidget->currentWidget()==symbolPage)
@@ -1976,7 +1933,7 @@ bool PlotDialog::acceptParams()
                        Graph::getPenStyle(boxPieLineStyle->currentIndex())));
       pie->setRay(boxRadius->value());
       pie->setBrushStyle(boxPiePattern->getSelectedPattern());
-      pie->setFirstColor(boxFirstColor->currentIndex());
+      pie->setFirstColor(boxFirstColor->colorIndex(boxFirstColor->color()));
     }
   else if (privateTabWidget->currentWidget() == percentilePage)
     {
@@ -2073,7 +2030,7 @@ bool PlotDialog::validInput()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr((histogramBeginBox->text()).toAscii().constData());
+			parser.SetExpr((histogramBeginBox->text()).toUtf8().constData());
 			start=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -2092,7 +2049,7 @@ bool PlotDialog::validInput()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr((histogramEndBox->text()).toAscii().constData());
+			parser.SetExpr((histogramEndBox->text()).toUtf8().constData());
 			end=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -2118,7 +2075,7 @@ bool PlotDialog::validInput()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr((binSizeBox->text()).toAscii().constData());
+			parser.SetExpr((binSizeBox->text()).toUtf8().constData());
 			stp=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -2155,30 +2112,6 @@ void PlotDialog::setPiePenStyle(const Qt::PenStyle& style)
 		boxPieLineStyle->setCurrentIndex(4);
 }
 
-void PlotDialog::setPenStyle(Qt::PenStyle style)
-{
-	switch (style)
-	{
-		case Qt::SolidLine:
-			boxLineStyle->setCurrentIndex(0);
-			break;
-		case Qt::DashLine:
-			boxLineStyle->setCurrentIndex(1);
-			break;
-		case Qt::DotLine:
-			boxLineStyle->setCurrentIndex(2);
-			break;
-		case Qt::DashDotLine:
-			boxLineStyle->setCurrentIndex(3);
-			break;
-		case Qt::DashDotDotLine:
-			boxLineStyle->setCurrentIndex(4);
-			break;
-		default:
-			break;
-	}
-}
-
 void PlotDialog::setBoxType(int index)
 {
 	boxCoeffLabel->hide();
@@ -2284,15 +2217,6 @@ void PlotDialog::showDefaultContourLinesBox(bool)
   		defaultPenBox->show();
 }
 
-void PlotDialog::pickContourLinesColor()
-{
-  	QColor color = QColorDialog::getColor(levelsColorBox->color(), this);
-  	if ( !color.isValid() || color == levelsColorBox->color() )
-  		return;
-
-  	levelsColorBox->setColor(color);
-}
-
 void PlotDialog::updateTreeWidgetItem(QTreeWidgetItem *item)
 {
     if (item->type() != QTreeWidgetItem::Type)
@@ -2307,6 +2231,12 @@ void PlotDialog::updateTreeWidgetItem(QTreeWidgetItem *item)
 void PlotDialog::updateBackgroundTransparency(int alpha)
 {
 	boxBackgroundColor->setEnabled(alpha);
+	if (alpha != boxBackgroundColor->color().alpha())
+	{
+		QColor c = boxBackgroundColor->color();
+		c.setAlpha(alpha);
+		boxBackgroundColor->setColor(c);
+	}
 
 	if (boxAll->isChecked())
 	{
@@ -2340,6 +2270,12 @@ void PlotDialog::updateBackgroundTransparency(int alpha)
 void PlotDialog::updateCanvasTransparency(int alpha)
 {
     boxCanvasColor->setEnabled(alpha);
+	if (alpha != boxCanvasColor->color().alpha())
+	{
+		QColor c = boxCanvasColor->color();
+		c.setAlpha(alpha);
+		boxCanvasColor->setColor(c);
+	}
 
 	if (boxAll->isChecked())
 	{
@@ -2370,14 +2306,12 @@ void PlotDialog::updateCanvasTransparency(int alpha)
 	}
 }
 
-void PlotDialog::pickCanvasColor()
+void PlotDialog::pickCanvasColor(QColor c)
 {
-	QColor c = QColorDialog::getColor(boxCanvasColor->color(), this);
-    if ( !c.isValid() || c == boxCanvasColor->color() )
-			return;
-
-	boxCanvasColor->setColor ( c ) ;
-
+	if (c.alpha() != boxCanvasTransparency->value())
+	{
+		boxCanvasTransparency->setValue(c.alpha());
+	}
 	if (boxAll->isChecked())
 	{
 		QWidgetList allPlots = d_ml->graphPtrs();
@@ -2407,14 +2341,12 @@ void PlotDialog::pickCanvasColor()
 	}
 }
 
-void PlotDialog::pickBackgroundColor()
+void PlotDialog::pickBackgroundColor(QColor c)
 {
-	QColor c = QColorDialog::getColor(boxBackgroundColor->color(), this);
-    if ( !c.isValid() || c == boxBackgroundColor->color() )
-			return;
-
-	boxBackgroundColor->setColor ( c ) ;
-
+	if (c.alpha() != boxBackgroundTransparency->value())
+	{
+		boxBackgroundTransparency->setValue(c.alpha());
+	}
 	if (boxAll->isChecked())
 	{
 		QWidgetList allPlots = d_ml->graphPtrs();
@@ -2444,14 +2376,8 @@ void PlotDialog::pickBackgroundColor()
 	}
 }
 
-void PlotDialog::pickBorderColor()
+void PlotDialog::pickBorderColor(QColor c)
 {
-	QColor c = QColorDialog::getColor(boxBorderColor->color(), this);
-	if ( !c.isValid() || c == boxBorderColor->color() )
-		return;
-
-	boxBorderColor->setColor ( c ) ;
-
 	if (boxAll->isChecked())
 	{
 		QWidgetList allPlots = d_ml->graphPtrs();
